@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Stenciller::Plugin::ToHtmlPreBlock;
-our $VERSION = '0.1207'; # VERSION:
+our $VERSION = '0.1208'; # VERSION:
 # ABSTRACT: A plugin that transforms to html
 
 use Moose;
@@ -56,7 +56,15 @@ __END__
 
 =pod
 
-:splint classname Stenciller::Plugin::ToHtmlPreBlock
+=encoding UTF-8
+
+=head1 NAME
+
+Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
+
+=head1 VERSION
+
+Version 0.1208, released 2015-02-08.
 
 =head1 SYNOPSIS
 
@@ -70,10 +78,31 @@ This plugin to L<Stenciller> places the C<before_input>, C<between> and C<after_
 
 Content that will be placed in C<pre> tags (input and output sections in stencils) also have four leading spaces removed.
 
+
+
 =head1 METHODS
 
 =head2 transform
 
 See L<transform|Stenciller::Transformer/"transform"> in L<Stenciller::Transformer>.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Stenciller>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Stenciller>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
