@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Stenciller::Plugin::ToUnparsedText;
-our $VERSION = '0.1207'; # VERSION:
+our $VERSION = '0.1208'; # VERSION:
 # ABSTRACT: A plugin that doesn't transform the text
 
 use Moose;
@@ -41,7 +41,15 @@ __END__
 
 =pod
 
-:splint classname Stenciller::Plugin::ToUnparsedText
+=encoding UTF-8
+
+=head1 NAME
+
+Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transform the text
+
+=head1 VERSION
+
+Version 0.1208, released 2015-02-08.
 
 =head1 SYNOPSIS
 
@@ -69,11 +77,31 @@ If this plugin is used via L<Pod::Elemental::Transformer::Stenciller> it could b
     # includes only the header_lines
     :stenciller ToUnparsedText atestfile-1.stencil { stencils => [] }
 
+
+
 =head1 METHODS
 
 =head2 transform
 
 See L<transform|Stenciller::Transformer/"transform"> in L<Stenciller::Transformer>.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Stenciller>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Stenciller>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
