@@ -1,6 +1,6 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1207'; # VERSION:
+our $VERSION = '0.1208'; # VERSION:
 # ABSTRACT: A role for transformer plugins to consume
 # PODNAME: Stenciller::Transformer
 
@@ -38,10 +38,19 @@ role Stenciller::Transformer using Moose {
 
 1;
 
+__END__
 
 =pod
 
-:splint classname Stenciller::Transformer
+=encoding UTF-8
+
+=head1 NAME
+
+Stenciller::Transformer - A role for transformer plugins to consume
+
+=head1 VERSION
+
+Version 0.1208, released 2015-02-08.
 
 =head1 SYNOPSIS
 
@@ -58,6 +67,8 @@ role Stenciller::Transformer using Moose {
 
 This is the role that all L<Stenciller> plugins must consume. It requires a C<transformer> method to be implemented.
 
+
+
 =head1 METHODS
 
 =head2 transform
@@ -96,10 +107,21 @@ examples, and create tests). It is not always necessary to include every stencil
 
 If C<require_in_extra> is given, it looks in the options hash for every stencil for the C<key> key.
 
-=for :list
-* If C<key> exists in the stencil's hash, and it has the C<value> value, then the stencil is parsed.
-* If C<key> exists in the stencil's hash, and it doesn't have the C<value> value, then the stencil is not parsed.
-* If C<key> doesn't exist in the stencil's hash, then the two first rules are applied as if the stencil had the C<default> value.
+=over 4
+
+=item *
+
+If C<key> exists in the stencil's hash, and it has the C<value> value, then the stencil is parsed.
+
+=item *
+
+If C<key> exists in the stencil's hash, and it doesn't have the C<value> value, then the stencil is not parsed.
+
+=item *
+
+If C<key> doesn't exist in the stencil's hash, then the two first rules are applied as if the stencil had the C<default> value.
+
+=back
 
 =head1 ATTRIBUTES
 
@@ -107,4 +129,23 @@ If C<require_in_extra> is given, it looks in the options hash for every stencil
 
 The L<Stenciller> object is passed automatically to plugins.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Stenciller>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Stenciller>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
